# device-specific setup
{
  pkgs,
  inputs,
  config,
  ...
}: {
  imports = with inputs; [
    chaotic.nixosModules.default
    lix.nixosModules.default
    self.nixosModules.desktop
    self.nixosModules.system
    ./hardware-conf.nix
    ./programs.nix
    ./stylix.nix
    ./users.nix
    ./sops.nix
  ];

  desktop = {
    hyprland.enable = true;
    # cosmic.enable = true;
  };

  nix = {
    settings.experimental-features = ["nix-command" "flakes"];
    distributedBuilds = true;
    settings.builders-use-substitutes = true;
    buildMachines = [
      {
        hostName = "dunamis";
        sshUser = "remotebuild";
        system = "x86_64-linux";
        sshKey = config.sops.secrets."ssh-private-eldrid-rmbuild".path;
        supportedFeatures = ["nixos-test" "big-parallel" "kvm" "benchmark"];
        publicHostKey = builtins.readFile "${inputs.mysecrets}/ssh/ssh_host_ed25519_dunamis.base64";
      }
    ];
  };

  system.stateVersion = "25.05";

  time.timeZone = "Europe/Kyiv";
  locale.ukrainian.enable = true;

  networking = {
    networkmanager.enable = true;
    hostName = "eldrid";
    # required for syncthing
    firewall = {
      allowedTCPPorts = [22000];
      allowedUDPPorts = [21027 22000];
    };
  };

  boot = {
    # kernelPackages = pkgs.linuxPackages_latest;
    kernelPackages = pkgs.linuxPackages_cachyos;
    plymouth.enable = true;
    loader.efi.canTouchEfiVariables = true;
    loader.systemd-boot = {
      enable = true;
      consoleMode = "auto";
    };
  };

  console = {
    earlySetup = true;
    packages = [pkgs.terminus_font];
    font = "${pkgs.terminus_font}/share/consolefonts/ter-c18n.psf.gz";
  };

  services = {
    power-profiles-daemon.enable = true;
    flatpak.enable = true;
    fstrim.enable = true;
    openssh.enable = true;
  };
  services.scx = {
    enable = true;
    scheduler = "scx_flash";
  };

  security.basic.enable = true;

  virtual = {
    libvirt.enable = true;
    podman.enable = false;
  };

  wireless.bluetooth.enableBlueman = true;

  opentabletdriver.enable = false;
  qmk-vial.enable = true;
}
